pub struct NewDenom {
pub name: String,
pub description: Option<String>,
pub symbol: String,
pub decimals: u32,
pub initial_balances: Option<Vec<InitialBalance>>,
}Fields
name: Stringdescription: Option<String>symbol: Stringdecimals: u32initial_balances: Option<Vec<InitialBalance>>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for NewDenom
impl<'de> Deserialize<'de> for NewDenom
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NewDenom
impl JsonSchema for NewDenom
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for NewDenom